@@ -43,12 +43,14 @@ static void gnome_canvas_group_ext_class_init   (GnomeCanvasGroupExtClass *class
 static void gnome_canvas_group_ext_init         (GnomeCanvasGroupExt     *group_ext);
 static void gnome_canvas_group_ext_print       (GPrintable *gprintable, GnomePrintContext *pc);
 static void gnome_canvas_group_ext_export_svg  (GPrintable *gprintable, xmlDocPtr doc, xmlNodePtr node);
+static void gnome_canvas_group_ext_draw_cairo  (GPrintable *gprintable, cairo_t *ct);
 
 static void
 gnome_canvas_group_print_init (GPrintableIface *iface)
 {
 	iface->print = gnome_canvas_group_ext_print;
 	iface->export_svg = gnome_canvas_group_ext_export_svg;
+	iface->draw_cairo = gnome_canvas_group_ext_draw_cairo;
 }
 
 GType
@@ -152,3 +154,26 @@ gnome_canvas_group_ext_export_svg (GPrintable *printable, xmlDocPtr doc, xmlNode
 		}
 	}
 }
+
+void gnome_canvas_group_ext_draw_cairo (GPrintable *printable, cairo_t *cr)
+{
+	GList *list;
+	double affine[6];
+	GnomeCanvasItem *item;
+	g_return_if_fail (GNOME_IS_CANVAS_GROUP_EXT (printable));
+	for (list = GNOME_CANVAS_GROUP (printable) ->item_list; list; list = list->next) {
+		item = GNOME_CANVAS_ITEM (list->data);
+		if (!(item->object.flags & GNOME_CANVAS_ITEM_VISIBLE))
+			continue;
+		if (GNOME_IS_CANVAS_GROUP_EXT(item))
+			gnome_canvas_group_ext_draw_cairo (G_PRINTABLE (item), cr);
+		else if (G_IS_PRINTABLE (item))
+		{
+			gnome_canvas_item_i2w_affine (item, affine);
+			cairo_save (cr);
+			cairo_transform (cr ,(cairo_matrix_t*) affine);
+			g_printable_draw_cairo (G_PRINTABLE (item), cr); 
+			cairo_restore (cr);
+		}
+	}
+}
