@@ -23,7 +23,7 @@
 #include "config.h"
 #include "element.h"
 #include "xml-utils.h"
-#include <goffice/utils/go-math.h>
+#include <goffice/math/go-math.h>
 #include <libxml/parser.h>
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
@@ -38,6 +38,8 @@
 #include <set>
 #include <string>
 
+using namespace std;
+
 static set<string>units;
 
 static void ReadValue (char const *source, GcuValue &value)
