@@ -52,13 +52,15 @@ static GOptionEntry options[] =
 {
 	{ "version", 'v', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (void*) cb_print_version, N_("Prints GChem3d Viewer version"), NULL },
 	{ "bgcolor", 'b', 0, G_OPTION_ARG_STRING, &bgcolor, N_("Background color: white, black or #rrggbb (default is black)"), NULL },
-	{ "display3d", 'd', 0, G_OPTION_ARG_STRING, &display3d, N_("How molecules are displayed; possible values are BallnStick (the default) and SpaceFill"), NULL },
+	{ "display3d", 'd', 0, G_OPTION_ARG_STRING, &display3d, N_("How molecules are displayed; possible values are BallnStick (the default), SpaceFill, Cylinders, and Wireframe"), NULL },
 	{ NULL }
 };
 
 static char const *Display3DModeNames[] = {
 	"ball&stick",
 	"spacefill",
+	"cylinders",
+	"wireframe"
 };
 
 static Display3DMode display3d_mode_from_string (char const *mode)
@@ -67,7 +69,7 @@ static Display3DMode display3d_mode_from_string (char const *mode)
 		return BALL_AND_STICK;
 	// first ensure the string is in lower case
 	char lcmode[16];
-	int i, max = strlen (mode), res = SPACEFILL;
+	int i, max = strlen (mode), res = WIREFRAME;
 	if (max > 15)
 		return BALL_AND_STICK;
 	for (i = 0; i < max; i++)
@@ -78,6 +80,7 @@ static Display3DMode display3d_mode_from_string (char const *mode)
 	return (Display3DMode) res;
 }
 
+
 int main(int argc, char *argv[])
 {
 	GnomeVFSURI *uri, *auri;
