@@ -37,6 +37,10 @@
 #include "prefs.h"
 #include "window.h"
 #include <glib/gi18n.h>
+#include <cstring>
+
+using namespace gcu;
+using namespace std;
 
 static unsigned short nNewDocs = 1;
 
@@ -63,7 +67,9 @@ void gcApplication::OnFileOpen ()
 {
 	list<string> l;
 	l.push_front ("application/x-gcrystal");
+#ifdef HAVE_OPENBABEL_2_2
 	l.push_front ("chemical/x-cif");
+#endif
 	FileChooser (this, false, l);
 }
 
@@ -277,8 +283,12 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 					return true;
 			}
 		}
-		if ((type == GCRYSTAL)? Doc->Import (filename, mime_type):
+		if ((type == GCRYSTAL)? Doc->Load (filename):
+#ifdef HAVE_OPENBABEL_2_2
 						Doc->Import (filename, mime_type)) {
+#else
+						false) {
+#endif
 			GtkRecentData data;
 			data.display_name = (char*) Doc->GetTitle ();
 			data.description = NULL;
