@@ -30,6 +30,12 @@
 #include <list>
 #include <cstring>
 
+// FIXME "the following lines should be removed for stable releases"
+#undef PACKAGE
+#define PACKAGE "gchemutils-unstable" 
+
+using namespace std;
+
 extern void on_show_curve (GObject *obj, char const* name);
 static void on_focus_in (GChemTableElt *dlg)
 {
@@ -145,6 +151,7 @@ GChemTableElt::GChemTableElt (GChemTableApp *App, int Z): Dialog (App, GLADEDIR"
 		buf = g_strdup_printf ("ei/%d", n);
 		g_object_set_data (G_OBJECT (button), "app", App);
 		g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_show_curve), (void*) buf);
+// FIXME: clean this on exit
 		n++;
 	}
 	gtk_widget_show_all (GTK_WIDGET (table));
@@ -249,8 +256,8 @@ GChemTableElt::GChemTableElt (GChemTableApp *App, int Z): Dialog (App, GLADEDIR"
 			j = radii_list.begin ();
 			jend = radii_list.end ();
 			while ((j != jend) && (((*j)->charge < (*radii)->charge) || 
-				(((*j)->charge == (*radii)->charge) && ((*j)->cn < (*radii)->cn) ||
-				(((*j)->cn == (*radii)->cn) && ((*j)->spin < (*radii)->spin)))))
+				(((*j)->charge == (*radii)->charge) && ((*j)->cn < (*radii)->cn)) ||
+				(((*j)->cn == (*radii)->cn) && ((*j)->spin < (*radii)->spin))))
 				j++;
 			radii_list.insert (j, *radii);
 			if ((*radii)->spin > maxspin)
@@ -296,7 +303,8 @@ GChemTableElt::GChemTableElt (GChemTableApp *App, int Z): Dialog (App, GLADEDIR"
 		gtk_tree_view_column_set_spacing (column, 5);
 		gtk_tree_view_append_column (tree, column);
 		jend = radii_list.end ();
-		char *ion, *cn, *spin;
+		char *ion, *cn;
+		char const *spin;
 		for (j = radii_list.begin (); j != jend; j++) {
 			if ((*j)->charge > 1)
 				ion = g_strdup_printf ("%s<sup>%d+</sup><sub> </sub>",elt->GetSymbol (),(*j)->charge);
@@ -315,7 +323,7 @@ GChemTableElt::GChemTableElt (GChemTableApp *App, int Z): Dialog (App, GLADEDIR"
 				spin = _("High");
 				break;
 			default:
-				spin = (char*) "";
+				spin = "";
 				break;
 			}
 			buf = gcu_dimensional_value_get_string (&(*j)->value);
